Crate twilight_cache_inmemory
source ·Expand description
twilight-cache-inmemory
twilight-cache-inmemory is an in-process-memory cache for the
twilight-rs ecosystem. It’s responsible for processing events and
caching things like guilds, channels, users, and voice states.
Statistics
Statistics can be an important debugging tool for determining how large a
cache is or determining whether a cache has an expected amount of resources
within it. An interface for retrieving statistics about the amount of a
resource within the cache as a whole or on a guild-level can be retrieved
via InMemoryCache::stats.
Features
By default no feature is enabled.
permission-calculator
The permission-calculator feature flag will bring in support for the
PermissionCalculator; an API for calculating permissions through it is
exposed via InMemoryCache::permissions. Support for calculating the
permissions of a member on a root guild-level and in a guild channel is
included.
Refer to the permission module for more documentation.
Examples
Update a cache with events that come in through the gateway:
use std::{env, error::Error};
use futures::stream::StreamExt;
use twilight_cache_inmemory::InMemoryCache;
use twilight_gateway::{Intents, Shard};
#[tokio::main]
async fn main() -> Result<(), Box<dyn Error>> {
let token = env::var("DISCORD_TOKEN")?;
let (shard, mut events) = Shard::new(token, Intents::GUILD_MESSAGES);
shard.start().await?;
// Create a cache, caching up to 10 messages per channel:
let cache = InMemoryCache::builder().message_cache_size(10).build();
while let Some(event) = events.next().await {
// Update the cache with the event.
cache.update(&event);
}
Ok(())
}License
All first-party crates are licensed under ISC
Re-exports
pub use self::permission::InMemoryCachePermissions;Modules
permission-calculatorStructs
InMemoryCache.InMemoryCache.