Struct twilight_cache_inmemory::model::CachedVoiceState
source · pub struct CachedVoiceState { /* private fields */ }Expand description
Represents a cached VoiceState.
Implementations
sourceimpl CachedVoiceState
impl CachedVoiceState
sourcepub const fn channel_id(&self) -> Id<ChannelMarker>
pub const fn channel_id(&self) -> Id<ChannelMarker>
ID of the channel that this user is connected to.
sourcepub const fn guild_id(&self) -> Id<GuildMarker>
pub const fn guild_id(&self) -> Id<GuildMarker>
ID of the guild that this user is connected in, if there is one.
sourcepub const fn request_to_speak_timestamp(&self) -> Option<Timestamp>
pub const fn request_to_speak_timestamp(&self) -> Option<Timestamp>
Timestamp of when the user requested to speak.
sourcepub const fn self_stream(&self) -> bool
pub const fn self_stream(&self) -> bool
Whether the user is streaming via “Go Live”.
sourcepub const fn self_video(&self) -> bool
pub const fn self_video(&self) -> bool
Whether the user’s camera is enabled.
sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
Session ID.
sourcepub const fn user_id(&self) -> Id<UserMarker>
pub const fn user_id(&self) -> Id<UserMarker>
ID of the user.