pub trait CacheableVoiceState:
From<(Id<ChannelMarker>, Id<GuildMarker>, VoiceState)>
+ PartialEq<VoiceState>
+ PartialEq<Self>
+ Clone
+ Debug {
// Required method
fn channel_id(&self) -> Id<ChannelMarker>;
}Expand description
Trait for a generic cached representation of a VoiceState.
Required Methods
Sourcefn channel_id(&self) -> Id<ChannelMarker>
fn channel_id(&self) -> Id<ChannelMarker>
ID of the channel this voice state belongs to.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".